@@ -1,7 +1,9 @@
 mod traits;
 
-use std::{cmp::Ordering, ops::Deref};
-use std::ops::Range;
+use std::{
+    cmp::Ordering,
+    ops::{Deref, Range},
+};
 
 /// Maybe have ast position
 pub type MaybeRanged = Option<Range<usize>>;
@@ -14,4 +16,3 @@ pub struct Literal<T> {
     /// The Start offset and end offset
     pub range: MaybeRanged,
 }
-
