@@ -1,18 +1,20 @@
 mod builder;
 mod cst_node;
-mod text_store;
 mod literal;
+mod text_store;
 
-#[cfg(feature = "lsp")]
 mod text_index;
 
-#[cfg(feature = "lsp")]
 pub use self::text_index::*;
 #[cfg(feature = "lsp")]
 pub use lsp_types;
 
-pub use self::{builder::ASTBuilder, cst_node::CSTNode, text_store::TextStore};
-pub use url::Url;
-pub use ropey::Rope;
+pub use self::{
+    builder::ASTBuilder,
+    cst_node::CSTNode,
+    literal::{Literal, MaybeRanged},
+    text_store::TextStore,
+};
 pub use dashmap::{DashMap, DashSet};
-pub use self::literal::{MaybeRanged, Literal};
\ No newline at end of file
+pub use ropey::Rope;
+pub use url::Url;
