@@ -1,11 +1,13 @@
-mod cst;
+#[cfg(feature = "lsp")]
+mod lsp;
 #[cfg(test)]
 mod test;
 mod traits;
 
-pub use lsp_types::{Position as LSPPosition, Range as LSPRange};
+#[cfg(feature = "lsp")]
+pub use lsp::{LSPPosition, LSPRange};
 
-use lsp_document::{IndexedText, TextAdapter, TextMap};
+use lsp_document::{IndexedText, TextMap};
 use std::ops::Range;
 
 /// Cache all newlines
@@ -56,22 +58,3 @@ impl TextIndex {
         }
     }
 }
-
-impl TextIndex {
-    #[inline]
-    pub fn get_lsp_range(&self, start: usize, end: usize) -> LSPRange {
-        let range = self.inner.offset_range_to_range(Range { start, end });
-        match range.and_then(|f| self.inner.range_to_lsp_range(&f)) {
-            Some(s) => s,
-            None => LSPRange { start: self.get_lsp_position(start), end: self.get_lsp_position(end) },
-        }
-    }
-    #[inline]
-    fn get_lsp_position(&self, offset: usize) -> LSPPosition {
-        let p = self.inner.offset_to_pos(offset.min(self.inner.text().len()));
-        match p.and_then(|f| self.inner.pos_to_lsp_pos(&f)) {
-            Some(s) => s,
-            None => LSPPosition { line: self.lines as u32 + 1, character: 0 },
-        }
-    }
-}
